@@ -27,18 +27,18 @@ BANDWIDTH_LIMIT_RULE_RESOURCE = 'bandwidth_limit_rule'
 def add_bandwidth_limit_arguments(parser):
     parser.add_argument(
         '--max-kbps',
-        help=_('max bandwidth in kbps.'))
+        help=_('Maximum bandwidth in kbps.'))
     parser.add_argument(
         '--max-burst-kbps',
-        help=_('max burst bandwidth in kbps.'))
+        help=_('Maximum burst bandwidth in kbps.'))
 
 
 def update_bandwidth_limit_args2body(parsed_args, body):
     max_kbps = parsed_args.max_kbps
     max_burst_kbps = parsed_args.max_burst_kbps
     if not (max_kbps or max_burst_kbps):
-        raise exceptions.CommandError(_("Must provide max_kbps"
-                                        " or max_burst_kbps option."))
+        raise exceptions.CommandError(_("Must provide max-kbps"
+                                        " or max-burst-kbps option."))
     neutronv20.update_dict(parsed_args, body,
                            ['max_kbps', 'max_burst_kbps', 'tenant_id'])
 
@@ -56,7 +56,7 @@ class CreateQoSBandwidthLimitRule(qos_rule.QosRuleMixin,
     def args2body(self, parsed_args):
         body = {}
         update_bandwidth_limit_args2body(parsed_args, body)
-        return {'bandwidth_limit_rule': body}
+        return {self.resource: body}
 
 
 class ListQoSBandwidthLimitRules(qos_rule.QosRuleMixin,
@@ -64,16 +64,10 @@ class ListQoSBandwidthLimitRules(qos_rule.QosRuleMixin,
     """List all qos bandwidth limit rules belonging to the specified policy."""
 
     resource = BANDWIDTH_LIMIT_RULE_RESOURCE
-
     _formatters = {}
     pagination_support = True
     sorting_support = True
 
-    def args2body(self, parsed_args):
-        body = {}
-        qos_rule.update_policy_args2body(parsed_args, body)
-        return {'qos_rule': body}
-
 
 class ShowQoSBandwidthLimitRule(qos_rule.QosRuleMixin, neutronv20.ShowCommand):
     """Show information about the given qos bandwidth limit rule."""
@@ -96,7 +90,7 @@ class UpdateQoSBandwidthLimitRule(qos_rule.QosRuleMixin,
     def args2body(self, parsed_args):
         body = {}
         update_bandwidth_limit_args2body(parsed_args, body)
-        return {'bandwidth_limit_rule': body}
+        return {self.resource: body}
 
 
 class DeleteQoSBandwidthLimitRule(qos_rule.QosRuleMixin,
