@@ -15,8 +15,8 @@
 #
 
 import sys
+from unittest import mock
 
-from mox3 import mox
 
 from neutronclient.common import exceptions
 from neutronclient.neutron import v2_0 as neutronV20
@@ -40,11 +40,12 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         netid = 'netid'
         cidr = '10.10.10.0/24'
         gateway = 'gatewayvalue'
-        args = ['--gateway', gateway, netid, cidr]
+        args = ['--gateway', gateway, netid, cidr, '--description', 'cave']
         position_names = ['ip_version', 'network_id', 'cidr', 'gateway_ip']
         position_values = [4, netid, cidr, gateway]
         self._test_create_resource(resource, cmd, name, myid, args,
-                                   position_names, position_values)
+                                   position_names, position_values,
+                                   description='cave')
 
     def test_create_subnet_network_cidr_seperated(self):
         # For positional value, network_id and cidr can be separated.
@@ -76,6 +77,23 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         self._test_create_resource(resource, cmd, name, myid, args,
                                    position_names, position_values)
 
+    def test_create_subnet_with_segment(self):
+        # Create subnet: --segment segment netid cidr.
+        resource = 'subnet'
+        cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
+        name = 'myname'
+        myid = 'myid'
+        netid = 'netid'
+        cidr = '10.10.10.0/24'
+        segment = 'segment'
+        args = ['--segment', segment, netid, cidr,
+                '--description', 'cave']
+        position_names = ['ip_version', 'network_id', 'cidr', 'segment_id']
+        position_values = [4, netid, cidr, segment]
+        self._test_create_resource(resource, cmd, name, myid, args,
+                                   position_names, position_values,
+                                   description='cave')
+
     def test_create_subnet_with_bad_gateway_option(self):
         # Create sbunet: --no-gateway netid cidr.
         resource = 'subnet'
@@ -400,12 +418,11 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         args = ['--gateway', gateway, netid, cidr]
         position_names = ['ip_version', 'network_id', 'cidr', 'gateway_ip']
         position_values = [4, netid, cidr, gateway]
-        self.mox.StubOutWithMock(cmd.log, 'warning')
-        cmd.log.warning(mox.IgnoreArg())
-        self._test_create_resource(resource, cmd, name, myid, args,
-                                   position_names, position_values)
-        self.mox.VerifyAll()
-        self.mox.UnsetStubs()
+        with mock.patch.object(cmd.log, 'warning') as mock_warning:
+            self._test_create_resource(resource, cmd, name, myid, args,
+                                       position_names, position_values)
+        mock_warning.assert_called_once_with(mock.ANY,
+                                             {'ip': 4, 'cidr': '/32'})
 
     def test_create_subnet_with_ipv6_ra_mode(self):
         resource = 'subnet'
@@ -502,7 +519,9 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
             position_values, tenant_id='tenantid',
             no_api_call=True, expected_exception=exceptions.CommandError)
 
-    def test_create_subnet_with_subnetpool_ipv6_and_ip_ver_ignored(self):
+    @mock.patch.object(neutronV20, 'find_resource_by_name_or_id')
+    def test_create_subnet_with_subnetpool_ipv6_and_ip_ver_ignored(
+            self, mock_find_resource):
         resource = 'subnet'
         cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
         name = 'myname'
@@ -514,17 +533,17 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
                 netid]
         position_names = ['ip_version', 'network_id', 'subnetpool_id']
         position_values = [6, netid, 'subnetpool_id']
-        self.mox.StubOutWithMock(neutronV20, 'find_resource_by_name_or_id')
-        neutronV20.find_resource_by_name_or_id(
-            self.client,
-            'subnetpool',
-            'subnetpool_id').AndReturn({'id': 'subnetpool_id',
-                                        'ip_version': 6})
+        mock_find_resource.return_value = {
+            'id': 'subnetpool_id', 'ip_version': 6}
         self._test_create_resource(
             resource, cmd, name, myid, args, position_names,
             position_values, tenant_id='tenantid')
+        mock_find_resource.assert_called_once_with(
+            self.client, 'subnetpool', 'subnetpool_id')
 
-    def test_create_subnet_with_subnetpool_ipv4_with_cidr_wildcard(self):
+    @mock.patch.object(neutronV20, 'find_resource_by_name_or_id')
+    def test_create_subnet_with_subnetpool_ipv4_with_cidr_wildcard(
+            self, mock_find_resource):
         resource = 'subnet'
         cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
         name = 'myname'
@@ -539,18 +558,18 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         position_names = ['ip_version', 'ipv6_address_mode',
                           'network_id', 'subnetpool_id', 'cidr']
         position_values = [4, None, netid, 'subnetpool_id', cidr]
-        self.mox.StubOutWithMock(neutronV20, 'find_resource_by_name_or_id')
-        neutronV20.find_resource_by_name_or_id(
-            self.client,
-            'subnetpool',
-            'subnetpool_id').AndReturn({'id': 'subnetpool_id',
-                                        'ip_version': 4})
+        mock_find_resource.return_value = {'id': 'subnetpool_id',
+                                           'ip_version': 4}
         self._test_create_resource(
             resource, cmd, name, myid, args, position_names,
             position_values, tenant_id='tenantid',
             no_api_call=True, expected_exception=exceptions.CommandError)
+        mock_find_resource.assert_called_once_with(
+            self.client, 'subnetpool', 'subnetpool_id')
 
-    def test_create_subnet_with_subnetpool_ipv4_with_prefixlen(self):
+    @mock.patch.object(neutronV20, 'find_resource_by_name_or_id')
+    def test_create_subnet_with_subnetpool_ipv4_with_prefixlen(
+            self, mock_find_resource):
         resource = 'subnet'
         cmd = subnet.CreateSubnet(test_cli20.MyApp(sys.stdout), None)
         name = 'myname'
@@ -565,16 +584,14 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         position_names = ['ip_version', 'ipv6_address_mode',
                           'network_id', 'subnetpool_id']
         position_values = [4, None, netid, 'subnetpool_id']
-        self.mox.StubOutWithMock(neutronV20, 'find_resource_by_name_or_id')
-        neutronV20.find_resource_by_name_or_id(
-            self.client,
-            'subnetpool',
-            'subnetpool_id').AndReturn({'id': 'subnetpool_id',
-                                        'ip_version': 4})
+        mock_find_resource.return_value = {'id': 'subnetpool_id',
+                                           'ip_version': 4}
         self._test_create_resource(
             resource, cmd, name, myid, args, position_names,
             position_values, tenant_id='tenantid',
             no_api_call=True, expected_exception=exceptions.CommandError)
+        mock_find_resource.assert_called_once_with(
+            self.client, 'subnetpool', 'subnetpool_id')
 
     def test_list_subnets_detail(self):
         # List subnets: -D.
@@ -627,9 +644,10 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         cmd = subnet.UpdateSubnet(test_cli20.MyApp(sys.stdout), None)
         self._test_update_resource(resource, cmd, 'myid',
                                    ['myid', '--name', 'myname',
+                                    '--description', 'cavern',
                                     '--tags', 'a', 'b'],
-                                   {'name': 'myname', 'tags': ['a', 'b'], }
-                                   )
+                                   {'name': 'myname', 'tags': ['a', 'b'],
+                                    'description': 'cavern'})
 
     def test_update_subnet_allocation_pools(self):
         # Update subnet: myid --name myname --tags a b.
@@ -646,15 +664,11 @@ class CLITestV20SubnetJSON(test_cli20.CLITestV20Base):
         # Update sbunet: --enable-dhcp and --disable-dhcp.
         resource = 'subnet'
         cmd = subnet.UpdateSubnet(test_cli20.MyApp(sys.stdout), None)
-        try:
-            self._test_update_resource(resource, cmd, 'myid',
-                                       ['myid', '--name', 'myname',
-                                        '--enable-dhcp', '--disable-dhcp'],
-                                       {'name': 'myname', }
-                                       )
-        except exceptions.CommandError:
-            return
-        self.fail('No exception for --enable-dhcp --disable-dhcp option')
+        self.assertRaises(exceptions.CommandError,
+                          self._test_update_resource,
+                          resource, cmd, 'myid',
+                          ['myid', '--name', 'myname', '--enable-dhcp',
+                           '--disable-dhcp'], {'name': 'myname', })
 
     def test_show_subnet(self):
         # Show subnet: --fields id --fields name myid.
